@@ -30,11 +30,10 @@
 #endif
 #include <stdio.h>
 #include <stdlib.h>
+#include <assert.h>
 #include <fcntl.h>
 #include <string.h>
 #include <errno.h>
-#include <rpc/rpc.h>
-#include <rpc/xdr.h>
 #ifdef HAVE_SYS_FILIO_H
 #include <sys/filio.h>
 #endif
@@ -42,6 +41,7 @@
 #include <sys/sockio.h>
 #endif
 #include <sys/types.h>
+#include "libnfs-zdr.h"
 #include "libnfs.h"
 #include "libnfs-raw.h"
 #include "libnfs-private.h"
@@ -70,12 +70,18 @@ static void set_nonblocking(int fd)
 
 int rpc_get_fd(struct rpc_context *rpc)
 {
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	return rpc->fd;
 }
 
 int rpc_which_events(struct rpc_context *rpc)
 {
-	int events = rpc->is_connected ? POLLIN : POLLOUT;
+	int events;
+
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
+	events = rpc->is_connected ? POLLIN : POLLOUT;
 
 	if (rpc->is_udp != 0) {
 		/* for udp sockets we only wait for pollin */
@@ -90,11 +96,10 @@ int rpc_which_events(struct rpc_context *rpc)
 
 static int rpc_write_to_socket(struct rpc_context *rpc)
 {
-	int64_t count;
+	int32_t count;
+
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
 
-	if (rpc == NULL) {
-		return -1;
-	}
 	if (rpc->fd == -1) {
 		rpc_set_error(rpc, "trying to write but not connected");
 		return -1;
@@ -134,7 +139,11 @@ static int rpc_read_from_socket(struct rpc_context *rpc)
 	int available;
 	int size;
 	int pdu_size;
-	int64_t count;
+	int32_t count;
+
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
 
 #if defined(WIN32)
 	if (ioctlsocket(rpc->fd, FIONREAD, &available) != 0) {
@@ -258,6 +267,8 @@ static int rpc_read_from_socket(struct rpc_context *rpc)
 
 int rpc_service(struct rpc_context *rpc, int revents)
 {
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	if (revents & POLLERR) {
 #ifdef WIN32
 		char err = 0;
@@ -336,11 +347,15 @@ int rpc_service(struct rpc_context *rpc, int revents)
 
 void rpc_set_autoreconnect(struct rpc_context *rpc)
 {
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	rpc->auto_reconnect = 1;
 }
 
 void rpc_unset_autoreconnect(struct rpc_context *rpc)
 {
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	rpc->auto_reconnect = 0;
 }
 
@@ -348,6 +363,8 @@ static int rpc_connect_sockaddr_async(struct rpc_context *rpc, struct sockaddr_s
 {
 	int socksize;
 
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	switch (s->ss_family) {
 	case AF_INET:
 		socksize = sizeof(struct sockaddr_in);
@@ -363,8 +380,6 @@ static int rpc_connect_sockaddr_async(struct rpc_context *rpc, struct sockaddr_s
 		return -1;
 	}
 
-
-#if !defined(WIN32)
 	/* Some systems allow you to set capabilities on an executable
 	 * to allow the file to be executed with privilege to bind to
 	 * privileged system ports, even if the user is not root.
@@ -379,42 +394,43 @@ static int rpc_connect_sockaddr_async(struct rpc_context *rpc, struct sockaddr_s
 	 * On linux, use
 	 *    sudo setcap 'cap_net_bind_service=+ep' /path/executable
 	 * to make the executable able to bind to a system port.
+	 *
+	 * On Windows, there is no concept of privileged ports. Thus
+	 * binding will usually succeed.
 	 */
-	if (1) {
-		static int port = 200;
-		int i;
-		int one = 1;
+	{
+		struct sockaddr_in sin;
+		static int portOfs = 0;
+		const int firstPort = 512;	/* >= 512 according to Sun docs */
+		const int portCount = IPPORT_RESERVED - firstPort;
+		int startOfs = portOfs, port, rc;
 
-		setsockopt(rpc->fd, SOL_SOCKET, SO_REUSEADDR, (char *)&one, sizeof(one));
+		do {
+			rc = -1;
+			port = htons(firstPort + portOfs);
+			portOfs = (portOfs + 1) % portCount;
 
-		for (i = 0; i < 500; i++) {
-			struct sockaddr_in sin;
+			/* skip well-known ports */
+			if (!getservbyport(port, "tcp")) {
+				memset(&sin, 0, sizeof(sin));
+				sin.sin_port        = port;
+				sin.sin_family      = AF_INET;
+				sin.sin_addr.s_addr = 0;
 
-			if(++port > 700) port = 200;
-
-			memset(&sin, 0, sizeof(sin));
-			sin.sin_port        = htons(port);
-			sin.sin_family      = AF_INET;
-			sin.sin_addr.s_addr = 0;
-
-			if (bind(rpc->fd, (struct sockaddr *)&sin, sizeof(struct sockaddr_in)) != 0 && errno != EACCES) {
-				/* we didnt get EACCES, so try again */
-				continue;
-			}
-			break;
-		}
-	}
+				rc = bind(rpc->fd, (struct sockaddr *)&sin, sizeof(struct sockaddr_in));
+#if !defined(WIN32)
+				/* we got EACCES, so don't try again */
+				if (rc != 0 && errno == EACCES)
+					break;
 #endif
+			}
+		} while (rc != 0 && portOfs != startOfs);
+	}
 
 	set_nonblocking(rpc->fd);
 
-#if defined(WIN32)
-	if (connect(rpc->fd, (struct sockaddr *)s, socksize) == 0 && errno != EINPROGRESS   )
-#else
-	if (connect(rpc->fd, (struct sockaddr *)s, socksize) != 0 && errno != EINPROGRESS) 
-#endif
-	{
-	  rpc_set_error(rpc, "connect() to server failed. %s(%d)", strerror(errno), errno);
+	if (connect(rpc->fd, (struct sockaddr *)s, socksize) != 0 && errno != EINPROGRESS) {
+		rpc_set_error(rpc, "connect() to server failed. %s(%d)", strerror(errno), errno);
 		return -1;
 	}		
 
@@ -425,6 +441,8 @@ int rpc_connect_async(struct rpc_context *rpc, const char *server, int port, rpc
 {
 	struct sockaddr_in *sin = (struct sockaddr_in *)&rpc->s;
 
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	if (rpc->fd != -1) {
 		rpc_set_error(rpc, "Trying to connect while already connected");
 		return -1;
@@ -465,6 +483,8 @@ int rpc_connect_async(struct rpc_context *rpc, const char *server, int port, rpc
 
 int rpc_disconnect(struct rpc_context *rpc, char *error)
 {
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	rpc_unset_autoreconnect(rpc);
 
 	if (rpc->fd != -1) {
@@ -485,6 +505,8 @@ int rpc_disconnect(struct rpc_context *rpc, char *error)
 
 static void reconnect_cb(struct rpc_context *rpc, int status, void *data _U_, void *private_data)
 {
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	if (status != RPC_STATUS_SUCCESS) {
 		rpc_error_all_pdus(rpc, "RPC ERROR: Failed to reconnect async");
 		return;
@@ -499,6 +521,8 @@ static int rpc_reconnect_requeue(struct rpc_context *rpc)
 {
 	struct rpc_pdu *pdu;
 
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	if (rpc->fd != -1) {
 #if defined(WIN32)
 		closesocket(rpc->fd);
@@ -538,6 +562,8 @@ int rpc_bind_udp(struct rpc_context *rpc, char *addr, int port)
 	struct addrinfo *ai = NULL;
 	char service[6];
 
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	if (rpc->is_udp == 0) {
 		rpc_set_error(rpc, "Cant not bind UDP. Not UDP context");
 		return -1;
@@ -581,6 +607,8 @@ int rpc_set_udp_destination(struct rpc_context *rpc, char *addr, int port, int i
 	struct addrinfo *ai = NULL;
 	char service[6];
 
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	if (rpc->is_udp == 0) {
 		rpc_set_error(rpc, "Can not set destination sockaddr. Not UDP context");
 		return -1;
@@ -600,6 +628,7 @@ int rpc_set_udp_destination(struct rpc_context *rpc, char *addr, int port, int i
 	rpc->udp_dest = malloc(ai->ai_addrlen);
 	if (rpc->udp_dest == NULL) {
 		rpc_set_error(rpc, "Out of memory. Failed to allocate sockaddr structure");
+		freeaddrinfo(ai);
 		return -1;
 	}
 	memcpy(rpc->udp_dest, ai->ai_addr, ai->ai_addrlen);
@@ -613,6 +642,8 @@ int rpc_set_udp_destination(struct rpc_context *rpc, char *addr, int port, int i
 
 struct sockaddr *rpc_get_recv_sockaddr(struct rpc_context *rpc)
 {
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	return (struct sockaddr *)&rpc->udp_src;
 }
 
@@ -621,6 +652,8 @@ int rpc_queue_length(struct rpc_context *rpc)
 	int i=0;
 	struct rpc_pdu *pdu;
 
+	assert(rpc->magic == RPC_CONTEXT_MAGIC);
+
 	for(pdu = rpc->outqueue; pdu; pdu = pdu->next) {
 		i++;
 	}
